import { MenuTheme } from 'antd/es/menu';

export type ContentWidth = 'Fluid' | 'Fixed';

export interface localeProps {
  key: string;
  icon: string;
  label: string;
}

export interface DefaultSettings {
  /**
   * theme for nav menu
   */
  navTheme: MenuTheme;
  /**
   * primary color of ant design 默认#1890FF
   */
  primaryColor: string;
  /**
   * nav menu position: `sidemenu` or `topmenu`
   */
  layout: 'sidemenu' | 'topmenu';
  /**
   * layout of content: `Fluid` or `Fixed`, only works when layout is topmenu
   */
  contentWidth: ContentWidth;
  /**
   * sticky header
   */
  fixedHeader: boolean;
  /**
   * auto hide header
   */
  autoHideHeader: boolean;
  /**
   * sticky siderbar
   */
  fixSiderbar: boolean;
  menu: { locale: boolean };
  title: string;
  pwa: boolean;
  // Your custom iconfont Symbol script Url
  // eg：//at.alicdn.com/t/font_1039637_btcrd5co4w.js
  // 注意：如果需要图标多色，Iconfont 图标项目里要进行批量去色处理
  // Usage: https://github.com/ant-design/ant-design-pro/pull/3517
  iconfontUrl: string;
  colorWeak: boolean;
  /**
   * 只有一种语言的时候,系统固话成一个语言,无导航栏选择框
   */
  locales: localeProps[];
}

export default {
  navTheme: 'dark',
  primaryColor: '#13C2C2',
  layout: 'sidemenu',
  contentWidth: 'Fluid',
  fixedHeader: true,
  autoHideHeader: false,
  fixSiderbar: true,
  colorWeak: false,
  menu: {
    locale: true,
  },
  title: 'KIM3.0平台业务架构',
  pwa: false,
  iconfontUrl: '',
  locales: [
    { key: 'zh-CN', label: '简体中文', icon: '🇨🇳' },
    // { key: 'zh-TW', label: '繁体中文', icon: '🇭🇰' },
    { key: 'en-US', label: 'English', icon: '🇬🇧' },
    // { key: 'pt-BR', label: 'Português', icon: '🇧🇷' },
  ],
} as DefaultSettings;
