import React from 'react';
import { connect } from 'dva';
import { message, Form, Select, InputNumber } from 'antd';
import Search from './search';
import Action from './action';
import Table from '../table';
import { generateUUID } from '@/utils';
import Ellipsis from '@/components/Ellipsis';

import styles from './index.less';

const FormItem = Form.Item;
@connect(({ paramBusiness, loading: { effects } }) => {
  const { list, pageData } = paramBusiness;
  return {
    list,
    pageData,
    loading:
      effects['paramBusiness/getList'] ||
      effects['paramBusiness/add'] ||
      effects['paramBusiness/update'] ||
      effects['paramBusiness/remove'],
  };
})
class Index extends React.Component {
  constructor(props) {
    super(props);
    this.search = null;
    this.table = null;
    this.queryParm = { pageNum: 1, pageSize: 10 };
    this.columns = [
      {
        title: '语言',
        dataIndex: 'paramLocale',
        width: '9%',
        editable: true,
        rules: [
          {
            required: true,
            message: '请输入参数模块',
          },
          {
            max: 50,
            message: '最大长度50',
          },
        ],
        render: text => (
          <Ellipsis lines={1} tooltip>
            {text}
          </Ellipsis>
        ),
      },
      {
        title: '参数模块',
        dataIndex: 'paramModule',
        width: '14%',
        editable: true,
        sorter: true,
        rules: [
          {
            required: true,
            message: '请输入值',
          },
          {
            max: 100,
            message: '最大长度100',
          },
        ],
        render: text => (
          <Ellipsis lines={1} tooltip>
            {text}
          </Ellipsis>
        ),
      },
      {
        title: '参数编码',
        dataIndex: 'paramCode',
        width: '12%',
        editable: true,
        sorter: true,
        rules: [
          {
            required: true,
            message: '请输入参数编码',
          },
          {
            max: 200,
            message: '最大长度200',
          },
        ],
        render: text => (
          <Ellipsis lines={1} tooltip>
            {text}
          </Ellipsis>
        ),
      },
      {
        title: '参数值',
        dataIndex: 'paramValue',
        width: '10%',
        editable: true,
        rules: [
          {
            required: true,
            message: '请输入参数值',
          },
          {
            max: 500,
            message: '最大长度500',
          },
        ],
        render: text => (
          <Ellipsis lines={1} tooltip>
            {text}
          </Ellipsis>
        ),
      },
      {
        title: '显示名称',
        dataIndex: 'paramName',
        width: '10%',
        editable: true,
        rules: [
          {
            required: true,
            message: '请输入显示名称',
          },
          {
            max: 200,
            message: '最大长度200',
          },
        ],
        render: text => (
          <Ellipsis lines={1} tooltip>
            {text}
          </Ellipsis>
        ),
      },
      {
        title: '说明',
        dataIndex: 'remark',
        // width: 100,
        editable: true,
        rules: [
          {
            max: 200,
            message: '最大长度200',
          },
        ],
        render: text => (
          <Ellipsis lines={1} tooltip>
            {text}
          </Ellipsis>
        ),
      },
      {
        title: '显示顺序',
        dataIndex: 'paramIndex',
        width: '9%',
        editable: true,
        renderEditing: ({ form, record, dataIndex }) => {
          const { getFieldDecorator } = form;
          return (
            <FormItem style={{ margin: 0 }}>
              {getFieldDecorator('paramIndex', {
                rules: [
                  {
                    required: true,
                    message: '请输入值',
                  },
                  {
                    type: 'number',
                    min: 1,
                    max: 1000,
                    message: '长度为1-1000',
                  },
                ],
                initialValue: record[dataIndex],
              })(<InputNumber min={1} max={1000} />)}
            </FormItem>
          );
        },
      },
      {
        title: '状态',
        dataIndex: 'paramState',
        width: '8%',
        editable: true,
        render: (text, record) => (String(record.paramState) === '1' ? '有效' : '无效'),
        renderEditing: ({ form, record }) => {
          const { getFieldDecorator } = form;
          return (
            <FormItem style={{ margin: 0 }}>
              {getFieldDecorator('paramState', {
                rules: [
                  {
                    required: true,
                    message: '请输入参数值',
                  },
                ],
                initialValue: String(record.paramState) || '1',
              })(
                <Select placeholder="请选择">
                  <Select.Option value="1">有效</Select.Option>
                  <Select.Option value="0">无效</Select.Option>
                </Select>,
              )}
            </FormItem>
          );
        },
      },
    ];
  }

  componentDidMount() {
    this.refreshList();
  }

  /**
   * 表格改变
   */
  onChangeTable = (pagination, filters, sorter) => {
    this.queryParm = {
      ...this.queryParm,
      pageNum: pagination.current,
      pageSize: pagination.pageSize,
      sortOrder: sorter.order,
      sortField: sorter.field,
    };

    this.refreshList();
  };

  /**
   * 查询
   */
  onClickQuery = () => {
    this.search.onSubmitForm(values => {
      this.queryParm = { ...this.queryParm, ...values, pageNum: 1 };
      this.refreshList();
    });
  };

  /**
   * 重置
   */
  onClickReset = () => {
    this.search.onResetForm();
    const { dispatch } = this.props;
    this.queryParm = { pageNum: 1 };
    dispatch({
      type: 'paramBusiness/getList',
      payload: this.queryParm,
    });
  };

  onSuccessUpload = () => {
    this.refreshList();
  };

  onClickExport = () => {
    const { dispatch } = this.props;
    this.search.onSubmitForm(values => {
      const params = { ...this.queryParm, ...values };
      dispatch({ type: 'paramBusiness/exportParam', params });
    });
  };

  // 添加行
  onClickAdd = () => {
    const row = {
      action: 'add',
      key: generateUUID(),
      paramSeq: '',
      paramModule: '',
      paramCode: '',
      paramValue: '',
      paramIndex: 1,
      remark: '',
      paramState: '1',
    };
    this.table.addRow(row);
  };

  handleSearch = n => {
    this.search = n;
  };

  handleTable = n => {
    this.table = n;
  };

  // 刷新列表
  refreshList = () => {
    const { dispatch } = this.props;
    dispatch({
      type: 'paramBusiness/getList',
      payload: this.queryParm,
    });
  };

  // 添加
  onAdd = async record => {
    const { dispatch } = this.props;
    const result = await dispatch({
      type: 'paramBusiness/add',
      payload: { ...record },
    });

    if (result) {
      message.success('添加成功');
      this.refreshList();
    }
    return result;
  };

  // 编辑
  onEdit = async record => {
    const { dispatch } = this.props;
    const result = await dispatch({
      type: 'paramBusiness/update',
      payload: { ...record },
    });
    if (result) {
      message.success('修改成功');
    }
    return result;
  };

  // 删除
  onDelete = async ({ paramId, goPrePage }) => {
    const { dispatch } = this.props;
    if (goPrePage) {
      this.queryParm.pageNum = this.queryParm.pageNum - 1;
    }
    const result = await dispatch({
      type: 'paramBusiness/remove',
      payload: { paramId },
    });
    if (result) {
      message.success('删除成功');
      this.refreshList();
    }
    return result;
  };

  render() {
    const { list, pageData, loading } = this.props;
    const tableProps = {
      dataSource: list,
      pageData,
      loading,
      onAdd: this.onAdd,
      onEdit: this.onEdit,
      onDelete: this.onDelete,
      onChangeTable: this.onChangeTable,
      columns: this.columns,
    };
    const actionProps = {
      onClickQuery: this.onClickQuery,
      onClickReset: this.onClickReset,
      onClickExport: this.onClickExport,
      onSuccessUpload: this.onSuccessUpload,
      onClickAdd: this.onClickAdd,
    };
    return (
      <div className={styles.root}>
        <Search wrappedComponentRef={this.handleSearch} />
        <Action {...actionProps} />
        <Table {...tableProps} wrappedComponentRef={this.handleTable} />
      </div>
    );
  }
}

export default Index;
